@@ -1,8 +1,10 @@
+from vipy.globals import print
 from vipy.util import mat2gray, try_import, string_to_pil_interpolation, Stopwatch, isnumpy
 try_import('cv2', 'opencv-python opencv-contrib-python'); import cv2
 import vipy.image
 from vipy.math import cartesian_to_polar
 import numpy as np
+try_import('scipy.interpolate', 'scipy')
 import scipy.interpolate
 import vipy.object
 import PIL.Image
