@@ -4,6 +4,7 @@ import PIL.Image
 import platform
 import dill
 import vipy.show
+from vipy.globals import print
 from vipy.show import imshow, imbbox, savefig, colorlist
 from vipy.util import isnumpy, isurl, isimageurl, \
     fileext, tempimage, mat2gray, imwrite, imwritegray, \
@@ -130,7 +131,7 @@ class Image(object):
         return str('<vipy.image: %s>' % (', '.join(strlist)))
 
     def print(self, prefix='', verbose=True):
-        """Print the representation of the image adn return self - useful for debugging in long fluent chains"""
+        """Print the representation of the image and return self - useful for debugging in long fluent chains"""
         if verbose:
             print(prefix+self.__repr__())
         return self
@@ -1542,7 +1543,7 @@ class Scene(ImageCategory):
         dy = padheight[0] if isinstance(padheight, tuple) and len(padheight) == 2 else padheight
         self._objectlist = [bb.translate(dx, dy) for bb in self._objectlist]
         return self
-    
+
     def rot90cw(self):
         """Rotate the scene 90 degrees clockwise, and update objects"""
         (H,W) = self.shape()        
@@ -1702,3 +1703,10 @@ def RandomScene(rows=None, cols=None, num_objects=16, url=None):
     return ims
     
 
+def owl():
+    """Return an owl image for testing"""
+    return Scene(url='https://upload.wikimedia.org/wikipedia/commons/thumb/2/23/Bubo_virginianus_06.jpg/1920px-Bubo_virginianus_06.jpg',
+                 category='Nature',
+                 objects=[vipy.object.Detection('Great Horned Owl', xmin=300, ymin=320, width=1200, height=1600),
+                          vipy.object.Detection('left eye', xmin=600, ymin=800, width=250, height=250), 
+                          vipy.object.Detection('right eye', xmin=1000, ymin=800, width=250, height=250)])
