@@ -13,7 +13,6 @@ import csv
 import hashlib
 import shutil
 import json
-import scipy.io
 import shelve
 import re
 import uuid
@@ -87,10 +86,6 @@ def count_images_in_subdirectories(indir):
     return num_files
 
 
-def quietprint(x, verbosity=None):
-    print(x)
-
-
 def rowvectorize(X):
     """Convert a 1D numpy array to a 2D row vector of size (1,N)"""
     return X.reshape((1, X. size)) if X.ndim == 1 else X
@@ -382,16 +377,6 @@ def loadh5(filename):
         raise ValueError('Invalid HDF5 file "%s" ' % filename)
 
 
-def savemat(outfile, vardict):
-    """Write a dictionary to .mat file"""
-    scipy.io.savemat(outfile, vardict)
-    return outfile
-
-
-def loadmat(infile):
-    """Read a dictionary to .mat file"""
-    return scipy.io.loadmat(infile)
-
 
 def loadmat73(matfile, keys=None):
     """Matlab 7.3 format, keys should be a list of keys to access HDF5
